@@ -18,18 +18,19 @@ the$status_running <- FALSE
 #'
 #' # Missing packages
 #'
-#' First, ensure that all packages used by the project are installed. This is
-#' important to do first because if any packages are missing we can't tell for
-#' sure that a package isn't used; it might be a dependency that we don’t know
-#' about.
+#' `status()` first checks that all packages used by the project are installed.
+#' This must be done first because if any packages are missing we can't tell for
+#' sure that a package isn't used; it might be a dependency that we don't know
+#' about. Once you have resolve any installation issues, you'll need to run
+#' `status()` again to reveal the next set of potential problems.
 #'
 #' There are four possibilities for an uninstalled package:
 #'
-#' * If it’s used and recorded, call `renv::restore()` to install the version
+#' * If it's used and recorded, call `renv::restore()` to install the version
 #'   specified in the lockfile.
-#' * If it’s used and not recorded, call `renv::install()` to install it
+#' * If it's used and not recorded, call `renv::install()` to install it
 #'   from CRAN or elsewhere.
-#' * If it’s not used and recorded, call `renv::snapshot()` to
+#' * If it's not used and recorded, call `renv::snapshot()` to
 #'   remove it from the lockfile.
 #' * If it's not used and not recorded, there's nothing to do. This the most
 #'   common state because you only use a small fraction of all available
@@ -46,12 +47,12 @@ the$status_running <- FALSE
 #' requires calling  `snapshot()` because there are four possibilities for
 #' a package:
 #'
-#' * If it’s used and recorded, it’s ok.
-#' * If it’s used and not recorded, call `renv::snapshot()` to add it to the
+#' * If it's used and recorded, it's ok.
+#' * If it's used and not recorded, call `renv::snapshot()` to add it to the
 #'   lockfile.
-#' * If it’s not used but is recorded, call `renv::snapshot()` to remove
+#' * If it's not used but is recorded, call `renv::snapshot()` to remove
 #'   it from the lockfile.
-#' * If it’s not used and not recorded, it’s also ok, as it may be a
+#' * If it's not used and not recorded, it's also ok, as it may be a
 #'   development dependency.
 #'
 #' # Out-of-sync sources
@@ -85,6 +86,8 @@ the$status_running <- FALSE
 #'   cache are installed at the expected + proper locations, and validate the
 #'   hashes used for those storage locations.
 #'
+#' @inheritParams dependencies
+#'
 #' @return This function is normally called for its side effects, but
 #'   it invisibly returns a list containing the following components:
 #'
@@ -100,7 +103,8 @@ status <- function(project = NULL,
                    library = NULL,
                    lockfile = NULL,
                    sources = TRUE,
-                   cache = FALSE)
+                   cache = FALSE,
+                   dev = FALSE)
 {
   renv_scope_error_handler()
   renv_dots_check(...)
@@ -108,70 +112,36 @@ status <- function(project = NULL,
   renv_snapshot_auto_suppress_next()
   renv_scope_options(renv.prompt.enabled = FALSE)
 
-  project <- renv_project_resolve(project)
-  renv_project_lock(project = project)
-
-  libpaths <- renv_libpaths_resolve(library)
-  lockpath <- lockfile %||% renv_lockfile_path(project)
-
-  invisible(renv_status_impl(project, libpaths, lockpath, sources, cache))
-}
-
-renv_status_check_initialized <- function(project, lockpath = NULL) {
-
-  projlib <- renv_paths_library(project = project)
-  lockpath <- lockpath %||% renv_paths_lockfile(project = project)
-
-  haslib <- file.exists(projlib)
-  haslock <- file.exists(lockpath)
-
-  if (haslib && haslock)
-    return(TRUE)
-
-  if (haslib && !haslock) {
-    writef(c(
-      "This project does not contain a lockfile.",
-      "Use renv::snapshot() to create a lockfile."
-    ))
-  } else if (!haslib && haslock) {
-    writef(c(
-      "There are no packages installed in the project library.",
-      "Use renv::restore() to install the packages defined in lockfile."
-    ))
-  } else {
-    writef(c(
-      "This project does not appear to be using renv.",
-      "Use renv::init() to initialize the project."
-    ))
-  }
-
-  FALSE
-
-}
-
-renv_status_impl <- function(project, libpaths, lockpath, sources, cache) {
-
-  # mark status as running
   the$status_running <- TRUE
   defer(the$status_running <- FALSE)
 
+  project <- renv_project_resolve(project)
+  renv_project_lock(project = project)
+
   # check to see if we've initialized this project
-  if (!renv_status_check_initialized(project, lockpath)) {
-    return(list(
+  if (!renv_status_check_initialized(project, library, lockfile)) {
+    result <- list(
       library = list(Packages = named(list())),
       lockfile = list(Packages = named(list())),
       synchronized = FALSE
-    ))
+    )
+    return(invisible(result))
   }
 
+  libpaths <- library %||% renv_libpaths_resolve()
+  lockpath <- lockfile %||% renv_paths_lockfile(project = project)
+
   # get all dependencies, including transitive
-  dependencies <- renv_snapshot_dependencies(project, dev = FALSE)
+  dependencies <- renv_snapshot_dependencies(project, dev = dev)
   packages <- sort(union(dependencies, "renv"))
   paths <- renv_package_dependencies(packages, libpaths = libpaths, project = project)
   packages <- as.character(names(paths))
 
   # read project lockfile
-  lockfile <- renv_lockfile_read(lockpath)
+  lockfile <- if (file.exists(lockpath))
+    renv_lockfile_read(lockpath)
+  else
+    renv_lockfile_init(project = project)
 
   # get lockfile capturing current library state
   library <- renv_lockfile_create(
@@ -209,12 +179,14 @@ renv_status_impl <- function(project, libpaths, lockpath, sources, cache) {
   else
     writef(c("", "See ?renv::status() for advice on resolving these issues."))
 
-  list(
+  result <- list(
     library      = library,
     lockfile     = lockfile,
     synchronized = synchronized
   )
 
+  invisible(result)
+
 }
 
 renv_status_check_unknown_sources <- function(project, lockfile) {
@@ -235,22 +207,26 @@ renv_status_check_consistent <- function(lockfile, library, used) {
     used = packages %in% used
   )
 
-  pkg_ok <- status$installed & (status$used == status$recorded)
-  if (all(pkg_ok)) {
+  ok <- status$installed & (status$used == status$recorded)
+  if (all(ok))
     return(TRUE)
-  }
 
   if (renv_verbose()) {
     # If any packages are not installed, we don't know for sure what's used
     # because our dependency graph is incomplete
-    missing <- any(!status$installed)
-
-    issues <- status[!pkg_ok, , drop = FALSE]
+    issues <- status[!ok, , drop = FALSE]
+    missing <- !issues$installed
     issues$installed <- ifelse(issues$installed, "y", "n")
     issues$recorded <- ifelse(issues$recorded, "y", "n")
-    issues$used <- ifelse(issues$used, "y", if (missing) "?" else "n")
+    issues$used <- ifelse(issues$used, "y", if (any(missing)) "?" else "n")
 
-    writef("The following package(s) are in an inconsistent state:")
+    if (any(missing)) {
+      msg <- "The following package(s) are missing:"
+      issues <- issues[missing, ]
+    } else {
+      msg <- "The following package(s) are in an inconsistent state:"
+    }
+    writef(msg)
     writef()
     print(issues, row.names = FALSE, right = FALSE)
   }
@@ -259,6 +235,47 @@ renv_status_check_consistent <- function(lockfile, library, used) {
 
 }
 
+renv_status_check_initialized <- function(project, library = NULL, lockfile = NULL) {
+
+  # only done if library and lockfile are NULL; that is, if the user
+  # is calling `renv::status()` without arguments
+  if (!is.null(library) || !is.null(lockfile))
+    return(TRUE)
+
+  # resolve paths to lockfile, primary library path
+  library  <- library  %||% renv_paths_library(project = project)
+  lockfile <- lockfile %||% renv_paths_lockfile(project = project)
+
+  # check whether the lockfile + library exist
+  haslib  <- all(file.exists(library))
+  haslock <- file.exists(lockfile)
+  if (haslib && haslock)
+    return(TRUE)
+
+  # TODO: what about the case where the library exists but no packages are installed?
+  # TODO: should this check for an 'renv/activate.R' script?
+  # TODO: what if a different project is loaded?
+  if (haslib && !haslock) {
+    writef(c(
+      "This project does not contain a lockfile.",
+      "Use `renv::snapshot()` to create a lockfile."
+    ))
+  } else if (!haslib && haslock) {
+    writef(c(
+      "There are no packages installed in the project library.",
+      "Use `renv::restore()` to install the packages defined in lockfile."
+    ))
+  } else {
+    writef(c(
+      "This project does not appear to be using renv.",
+      "Use `renv::init()` to initialize the project."
+    ))
+  }
+
+  FALSE
+
+}
+
 renv_status_check_synchronized <- function(lockfile, library) {
 
   lockfile <- renv_lockfile_records(lockfile)
