@@ -229,3 +229,36 @@ test_that("init() prompts the user for the snapshot type", {
   expect_true(renv_package_installed("bread"))
 
 })
+
+test_that("a project can be initialized without loading it", {
+  skip_on_cran()
+
+  project <- renv_tests_scope()
+  init()
+  expect_equal(renv_project_get(), project)
+
+  oldwd <- getwd()
+  oldrepos <- getOption("repos")
+  oldlibs <- .libPaths()
+
+  other <- renv_scope_tempfile("renv-project-")
+  ensure_directory(other)
+  init(project = other, load = FALSE, restart = FALSE)
+  expect_equal(renv_project_get(), project)
+  expect_true(file.exists(file.path(other, "renv.lock")))
+
+  expect_equal(oldwd, getwd())
+  expect_equal(oldrepos, getOption("repos"))
+  expect_equal(oldlibs, .libPaths())
+})
+
+test_that("init() respects user-requested snapshot type", {
+  project <- renv_tests_scope()
+  writeLines("Depends: bread", con = "DESCRIPTION")
+  writeLines("library(toast)", con = "deps.R")
+  init()
+
+  expect_true(renv_package_installed("bread"))
+  expect_false(renv_package_installed("toast"))
+  expect_equal(settings$snapshot.type(), "explicit")
+})
