@@ -1,6 +1,4 @@
 
-context("Profiles")
-
 test_that("library paths set in a user profile are overridden after load", {
   skip_on_cran()
   skip_on_os("windows")
@@ -32,8 +30,6 @@ test_that("library paths set in a user profile are overridden after load", {
 
 test_that(".First is executed; library paths are restored after", {
 
-  skip("only implemented when sandbox running?")
-
   skip_on_cran()
   skip_on_os("windows")
 
@@ -43,7 +39,7 @@ test_that(".First is executed; library paths are restored after", {
   renv_imbue_impl(project = getwd(), force = TRUE)
 
   # add a .First to the profile
-  profile <- code({
+  profile <- quote({
 
     .First <- function() {
       writeLines("Hello from .First")
@@ -56,7 +52,7 @@ test_that(".First is executed; library paths are restored after", {
 
   # ensure profile is executed
   renv_scope_envvars(R_PROFILE_USER = NULL)
-  writeLines(profile, con = ".Rprofile")
+  writeLines(deparse(profile), con = ".Rprofile")
 
   # invoke R
   script <- renv_test_code({
